@@ -17,7 +17,7 @@ limitations under the License.
 import abc
 import warnings
 from functools import wraps
-from typing import Tuple
+from typing import List, Tuple
 
 import numpy as np
 
@@ -68,6 +68,14 @@ errors or code that doesn't behave as expected. Consider using one of the
 functions documented here: https://www.cvxpy.org/tutorial/functions/index.html
 """
 
+__INPLACE_MUTATION_ERROR__ = """
+You're trying to mutate a CVXPY expression inplace. This is prone to errors or
+code that doesn't behave as expected. Consider alternatives. For example, replace
+    x += 1
+with
+    x = x + 1
+"""
+
 __ABS_ERROR__ = """
 You're calling the built-in abs function on a CVXPY expression. This is not
 supported. Consider using the abs function provided by CVXPY.
@@ -163,6 +171,27 @@ class Expression(u.Canonical):
         return self
 
     # Curvature properties.
+    @property
+    def curvatures(self) -> List[str]:
+        """List : Returns a list of the curvatures of the expression."""
+        curvatures = [
+            (self.is_constant, s.CONSTANT),
+            (self.is_affine, s.AFFINE),
+            (self.is_convex, s.CONVEX),
+            (self.is_concave, s.CONCAVE),
+            (self.is_log_log_constant, s.LOG_LOG_CONSTANT),
+            (self.is_log_log_affine, s.LOG_LOG_AFFINE),
+            (self.is_log_log_convex, s.LOG_LOG_CONVEX),
+            (self.is_log_log_concave, s.LOG_LOG_CONCAVE),
+            (self.is_quasilinear, s.QUASILINEAR),
+            (self.is_quasiconvex, s.QUASICONVEX),
+            (self.is_quasiconcave, s.QUASICONCAVE),
+        ]
+        curvatures = [curvature for condition, curvature in curvatures if condition()]
+        if not curvatures:
+            return [s.UNKNOWN]
+        return curvatures
+
     @property
     def curvature(self) -> str:
         """str : The curvature of the expression.
@@ -746,6 +775,14 @@ class Expression(u.Canonical):
                     len(args) == 2 and \
                     args[1] is self:
                 return ufunc_handler(self, args[0])
+            elif kwargs.keys() == {'out'} and \
+                    len(args) == 2 and \
+                    args[1] is self and \
+                    isinstance(kwargs['out'], tuple) and \
+                    len(kwargs['out']) == 1 and \
+                    args[0] is kwargs['out'][0]:
+                raise RuntimeError(__INPLACE_MUTATION_ERROR__)
+
         except KeyError:
             pass
 
@@ -844,4 +881,3 @@ class Expression(u.Canonical):
         """
         from cvxpy import var
         return var(self, ddof=ddof)
-
