@@ -35,7 +35,12 @@ from cvxpy.expressions.variable import Variable
 from cvxpy.problems.objective import Minimize
 from cvxpy.problems.param_prob import ParamProb
 from cvxpy.reductions import InverseData, Solution, cvx_attr2constr
-from cvxpy.reductions.matrix_stuffing import MatrixStuffing, extract_mip_idx
+from cvxpy.reductions.matrix_stuffing import (
+    MatrixStuffing,
+    extract_lower_bounds,
+    extract_mip_idx,
+    extract_upper_bounds,
+)
 from cvxpy.reductions.utilities import (
     ReducedMat,
     are_args_affine,
@@ -138,7 +143,10 @@ class ParamConeProg(ParamProb):
                  parameters,
                  param_id_to_col,
                  P=None,
-                 formatted: bool = False) -> None:
+                 formatted: bool = False,
+                 lower_bounds: np.ndarray | None = None,
+                 upper_bounds: np.ndarray | None = None,
+                 ) -> None:
         # The problem data tensors; c is for the constraint, and A for
         # the problem data matrix
         self.c = c
@@ -146,6 +154,9 @@ class ParamConeProg(ParamProb):
         self.P = P
         # The variable
         self.x = x
+        # Lower and upper bounds for the variable, if present.
+        self.lower_bounds = lower_bounds
+        self.upper_bounds = upper_bounds
 
         # Form a reduced representation of A and P, for faster application
         # of parameters.
@@ -368,15 +379,22 @@ class ConeMatrixStuffing(MatrixStuffing):
         params_to_problem_data = extractor.affine(expr_list)
 
         inverse_data.minimize = type(problem.objective) == Minimize
-        new_prob = ParamConeProg(params_to_c,
-                                 flattened_variable,
-                                 params_to_problem_data,
-                                 problem.variables(),
-                                 inverse_data.var_offsets,
-                                 ordered_cons,
-                                 problem.parameters(),
-                                 inverse_data.param_id_map,
-                                 P=params_to_P)
+        variables = problem.variables()
+        lower_bounds = extract_lower_bounds(variables, flattened_variable.size)
+        upper_bounds = extract_upper_bounds(variables, flattened_variable.size)
+        new_prob = ParamConeProg(
+            params_to_c,
+            flattened_variable,
+            params_to_problem_data,
+            variables,
+            inverse_data.var_offsets,
+            ordered_cons,
+            problem.parameters(),
+            inverse_data.param_id_map,
+            P=params_to_P,
+            lower_bounds=lower_bounds,
+            upper_bounds=upper_bounds,
+        )
         return new_prob, inverse_data
 
     def invert(self, solution, inverse_data):
