@@ -204,7 +204,7 @@ class TestConstraints(BaseTest):
         self.assertEqual(constr.size, 3)
 
         # Test invalid dimensions.
-        error_str = ("Argument dimensions (np.int32(1),) and (np.int32(1), np.int32(4)), with axis=0, "
+        error_str = ("Argument dimensions (1,) and (1, 4), with axis=0, "
                      "are incompatible.")
         with self.assertRaises(Exception) as cm:
             SOC(Variable(1), Variable((1, 4)))
